==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/RFQPROJECTBUDGET_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour RFQPROJECTBUDGET_type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RFQPROJECTBUDGET_type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROJECTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BUDGETID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQPROJECTBUDGET_type", propOrder = {
    "projectid",
    "budgetid"
})
public class RFQPROJECTBUDGET_Type {

    @XmlElement(name = "PROJECTID", required = true)
    protected PROJECTID_Type projectid;
    @XmlElement(name = "BUDGETID")
    protected BUDGET_Type budgetid;

    /**
     * Obtient la valeur de la propriété projectid.
     * 
     * @return
     *     possible object is
     *     {@link PROJECTID_Type }
     *     
     */
    public PROJECTID_Type getPROJECTID() {
        return projectid;
    }

    /**
     * Définit la valeur de la propriété projectid.
     * 
     * @param value
     *     allowed object is
     *     {@link PROJECTID_Type }
     *     
     */
    public void setPROJECTID(PROJECTID_Type value) {
        this.projectid = value;
    }

    /**
     * Obtient la valeur de la propriété budgetid.
     * 
     * @return
     *     possible object is
     *     {@link BUDGET_Type }
     *     
     */
    public BUDGET_Type getBUDGETID() {
        return budgetid;
    }

    /**
     * Définit la valeur de la propriété budgetid.
     * 
     * @param value
     *     allowed object is
     *     {@link BUDGET_Type }
     *     
     */
    public void setBUDGETID(BUDGET_Type value) {
        this.budgetid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/RFQPROJECTBUDGET_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RFQPROJECTBUDGET_type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RFQPROJECTBUDGET_type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROJECTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BUDGETID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQPROJECTBUDGET_type", propOrder = {
    "projectid",
    "budgetid"
})
public class RFQPROJECTBUDGET_Type {

    @XmlElement(name = "PROJECTID", required = true)
    protected PROJECTID_Type projectid;
    @XmlElement(name = "BUDGETID")
    protected BUDGET_Type budgetid;

    /**
     * Gets the value of the projectid property.
     * 
     * @return
     *     possible object is
     *     {@link PROJECTID_Type }
     *     
     */
    public PROJECTID_Type getPROJECTID() {
        return projectid;
    }

    /**
     * Sets the value of the projectid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PROJECTID_Type }
     *     
     */
    public void setPROJECTID(PROJECTID_Type value) {
        this.projectid = value;
    }

    /**
     * Gets the value of the budgetid property.
     * 
     * @return
     *     possible object is
     *     {@link BUDGET_Type }
     *     
     */
    public BUDGET_Type getBUDGETID() {
        return budgetid;
    }

    /**
     * Sets the value of the budgetid property.
     * 
     * @param value
     *     allowed object is
     *     {@link BUDGET_Type }
     *     
     */
    public void setBUDGETID(BUDGET_Type value) {
        this.budgetid = value;
    }

}
